@@ -8,7 +8,7 @@ use Crypt::OpenSSL::Verify;
 use Crypt::OpenSSL::X509;
 use HTTP::Request::Common;
 use LWP::UserAgent;
-use XML::XPath;
+use XML::LibXML;
 
 
 has 'entityid' => (isa => 'Str',          is => 'ro', required => 1);
@@ -38,9 +38,15 @@ sub new_from_url {
 sub new_from_xml {
     my($class, %args) = @_;
 
-    my $xpath = XML::XPath->new(xml => no_comments($args{xml}));
-    $xpath->set_namespace('md', 'urn:oasis:names:tc:SAML:2.0:metadata');
-    $xpath->set_namespace('ds', 'http://www.w3.org/2000/09/xmldsig#');
+    my $dom = XML::LibXML->load_xml(
+                    string => no_comments($args{xml}),
+                    no_network => 1,
+                    load_ext_dtd => 0,
+                    expand_entities => 0 );
+
+    my $xpath = XML::LibXML::XPathContext->new($dom);
+    $xpath->registerNs('md', 'urn:oasis:names:tc:SAML:2.0:metadata');
+    $xpath->registerNs('ds', 'http://www.w3.org/2000/09/xmldsig#');
 
     my $data;
 
@@ -121,7 +127,7 @@ sub new_from_xml {
     }
 
     my $self = $class->new(
-        entityid       => $xpath->findvalue('//md:EntityDescriptor/@entityID')->value,
+        entityid       => $xpath->findvalue('//md:EntityDescriptor/@entityID'),
         sso_urls       => $data->{SSO},
         slo_urls       => $data->{SLO} || {},
         art_urls       => $data->{Art} || {},
@@ -220,7 +226,7 @@ Net::SAML2::IdP
 
 =head1 VERSION
 
-version 0.33
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -293,20 +299,11 @@ If no NameID formats were advertised by the IdP, returns undef.
 
 =head1 AUTHOR
 
-Original Author: Chris Andrews  <chrisa@cpan.org>
+Chris Andrews  <chrisa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Chris Andrews and Others; in detail:
-
-  Copyright 2010-2011  Chris Andrews
-            2012       Peter Marschall
-            2015       Mike Wisener
-            2016       Jeff Fearn
-            2017       Alessandro Ranellucci
-            2019       Timothy Legge
-            2020       Timothy Legge, Wesley Schwengle
-
+This software is copyright (c) 2021 by Chris Andrews and Others, see the git log.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
