@@ -9,7 +9,7 @@ use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
 # Based on XML::Sig VERSION = '0.47';
-$VERSION = '0.33';
+$VERSION = '0.35';
 
 use base qw(Class::Accessor);
 Net::SAML2::XML::Sig->mk_accessors(qw(key));
@@ -1478,7 +1478,7 @@ Net::SAML2::XML::Sig
 
 =head1 VERSION
 
-version 0.33
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -1793,18 +1793,11 @@ Maintainer: Timothy Legge <timlegge@cpan.org>
 
 =head1 AUTHOR
 
-Original Author: Chris Andrews  <chrisa@cpan.org>
+Chris Andrews  <chrisa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Chris Andrews and Others; in detail:
-
-  Copyright 2011       Chris Andrews, Oskari Okko Ojala
-            2012       Chris Andrews, Peter Marschall
-            2016       Jeff Fearn
-            2017       Mike Wisener, xmikew
-            2019-2021  Timothy Legge
-
+This software is copyright (c) 2021 by Chris Andrews and Others, see the git log.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -1814,3 +1807,4 @@ the same terms as the Perl 5 programming language system itself.
 __END__
 
 }
+
